summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/seta001.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/seta001.cpp')
-rw-r--r--src/mame/video/seta001.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/video/seta001.cpp b/src/mame/video/seta001.cpp
index 67ead040f9b..320d73d70af 100644
--- a/src/mame/video/seta001.cpp
+++ b/src/mame/video/seta001.cpp
@@ -39,13 +39,13 @@ seta001_device::seta001_device(const machine_config &mconfig, const char *tag, d
}
//-------------------------------------------------
// static_set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------
-void seta001_device::static_set_gfxdecode_tag(device_t &device, const char *tag)
+void seta001_device::set_gfxdecode_tag(const char *tag)
{
- downcast<seta001_device &>(device).m_gfxdecode.set_tag(tag);
+ m_gfxdecode.set_tag(tag);
}
void seta001_device::device_start()
@@ -39,13 +39,13 @@ seta001_device::seta001_device(const machine_config &mconfig, const char *tag, d
}
//-------------------------------------------------
-// static_set_gfxdecode_tag: Set the tag of the
+// set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------